Generator generates final output for showing.

Re-exports

pub use self::tui::TuiTextGenerator;
tui
pub use self::ansi::ANSIStringsGenerator;
ansi
pub use self::crossterm::CrosstermCommandsGenerator;
crossterm

Modules

ansiansi
Generator for asni terminal string.
crosstermcrossterm
Generator implementations for crossterm crate.
Helper functions for create generator.
tuitui
Generator implementations for tui crate.

Enums

Tag of a Element after tag conversion stage.

Traits

Generator generates final output to show tui markup in some backend.
Trait for convert a raw tag string to Tag type.

Type Definitions

Tag type for a generator G.