pub enum Item<'a, Tag = LSpan<'a>> {
    PlainText(LSpan<'a>),
    Element(Vec<Tag>, Vec<Item<'a, Tag>>),
}
AST item.

In parsing stage, each line of source code will be parsed as a Vec<Item>, so the final result is Vec<Vec<Item>>.

Tag conversion stage, Each tag will be converted from LSpan into Tag type the generator needed, by using TagConvertor of the generator.

In generating stage, generator will convert Vec<Vec<Item<'_, Tag>>>> to final output.

Variants

PlainText(LSpan<'a>)

Plain text(escaped) without any style.

Element(Vec<Tag>, Vec<Item<'a, Tag>>)

A styled element, contains a series tag name and subitems.