Function tui_markup::compile_with
source · [−]pub fn compile_with<'a, G>(
s: &'a str,
gen: G
) -> Result<G::Output, Error<'a, G::Err>>where
G: Generator<'a>,Expand description
Parse markup language source, then generate final output using the provided generator.
See document of generator type for examples.
Errors
If input source contains invalid syntax or generator failed.