Generator generates final output for showing.

Re-exports

pub use self::tui::TuiTextGenerator;
tui

Modules

Helper functions for create generator.

Generator implementations tui crate.

Enums

Tag of a Element after transform step.

Traits

Generator generates final output to show tui markup in some backend.

Trait for convert a raw tag string to tag type.

Type Definitions

Tag type for a generator G.