Module tui_markup::generator
source · [−]Expand description
Generator generates final output for showing.
Re-exports
pub use self::tui::TuiTextGenerator;tuiModules
Enums
Traits
Generator generates final output to show tui markup in some backend.
Trait for convert a raw tag string to tag type.
Type Definitions
Tag type for a generator G.